pytest-9.0.3
=======================================

pytest 9.0.3 has just been released to PyPI.

This is a bug-fix release, being a drop-in replacement.

The full changelog is available at https://docs.pytest.org/en/stable/changelog.html.

Thanks to all of the contributors to this release:

* Aditya Giri
* Alejandro Villate
* Bruno Oliveira
* Bubble-Interface
* Charles-Meldhine Madi Mnemoi
* DavidAG
* Denis Cherednichenko
* Dr Alex Mitre
* Freya
* Freya Bruhin
* Hugo van Kemenade
* John Litborn
* Liam DeVoe
* Lily Wu
* Maxime Grenu
* Ran Benita
* Randy Döring
* Ronald Eddy Jr
* Samuel Newbold
* Tejas Verma
* Vladimir
* jxramos
* 🇺🇦 Sviatoslav Sydorenko (Святослав Сидоренко)


Happy testing,
The pytest Development Team
